@@ -1,16 +1,20 @@
 import time
-from importlib import import_module
 
+from django import VERSION
 from django.conf import settings
-from django.contrib.sessions.backends.base import UpdateError
-from django.contrib.sessions.middleware import SessionMiddleware
 from django.core.exceptions import SuspiciousOperation
 from django.utils.cache import patch_vary_headers
 from django.utils.http import http_date
 
+from django.contrib.sessions.backends.base import UpdateError
+from django.contrib.sessions.middleware import SessionMiddleware
+
+django_version = float("{}.{}".format(*VERSION[:2]))
+SAMESITE_NONE = None if django_version < 3.1 else "None"
+
 
 class SamlSessionMiddleware(SessionMiddleware):
-    cookie_name = getattr(settings, 'SAML_SESSION_COOKIE_NAME', 'saml_session')
+    cookie_name = getattr(settings, "SAML_SESSION_COOKIE_NAME", "saml_session")
 
     def process_request(self, request):
         session_key = request.COOKIES.get(self.cookie_name, None)
@@ -35,12 +39,12 @@ class SamlSessionMiddleware(SessionMiddleware):
                 self.cookie_name,
                 path=settings.SESSION_COOKIE_PATH,
                 domain=settings.SESSION_COOKIE_DOMAIN,
-                samesite=None,
+                samesite=SAMESITE_NONE,
             )
-            patch_vary_headers(response, ('Cookie',))
+            patch_vary_headers(response, ("Cookie",))
         else:
             if accessed:
-                patch_vary_headers(response, ('Cookie',))
+                patch_vary_headers(response, ("Cookie",))
             # relies and the global one
             if (modified or settings.SESSION_SAVE_EVERY_REQUEST) and not empty:
                 if request.saml_session.get_expire_at_browser_close():
@@ -65,10 +69,11 @@ class SamlSessionMiddleware(SessionMiddleware):
                         self.cookie_name,
                         request.saml_session.session_key,
                         max_age=max_age,
-                        expires=expires, domain=settings.SESSION_COOKIE_DOMAIN,
+                        expires=expires,
+                        domain=settings.SESSION_COOKIE_DOMAIN,
                         path=settings.SESSION_COOKIE_PATH,
                         secure=settings.SESSION_COOKIE_SECURE or None,
                         httponly=settings.SESSION_COOKIE_HTTPONLY or None,
-                        samesite=None
+                        samesite=SAMESITE_NONE,
                     )
         return response
