@@ -17,8 +17,8 @@
 import os
 import sys
 
-from django.core.wsgi import get_wsgi_application
 from django.core import management
+from django.core.wsgi import get_wsgi_application
 
 PROJECT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir))
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tests.settings")
@@ -26,4 +26,4 @@ sys.path.append(PROJECT_DIR)
 # Load models
 application = get_wsgi_application()
 
-management.call_command('test', 'djangosaml2.tests', 'testprofiles')
+management.call_command("test", "djangosaml2.tests", "testprofiles")
